#include <stdio.h>

#include "mrk/parser_internal.h"

const char *unexpected_path_msg =
    "You should never see this error; please report it.";

mrk_parser_err mrk_parser_err_code(mrk_parser *parser) {
  return parser->error.code;
}

const char *mrk_parser_err_msg(mrk_parser *parser) {
  switch (parser->error.code) {
  case mrk_parser_err_ok:
    parser->error.buf[0] = '\0';
    break;
  case mrk_parser_err_unexpected_token:
    sprintf(parser->error.buf, "%lu:%lu: unexpected token type %i",
            parser->error.token.start_line,
            parser->error.token.start_line_index, parser->error.token.type);
    break;
  case mrk_parser_err_unexpected_eat:
    sprintf(parser->error.buf,
            "%lu:%lu: unexpected token, expected type %i but got %i",
            parser->error.token.start_line,
            parser->error.token.start_line_index,
            parser->error.expected_token_type, parser->error.token.type);
    break;
  case mrk_parser_unclosed_brackets:
    sprintf(parser->error.buf, "%lu:%lu: unclosed bracket",
            parser->error.token.start_line,
            parser->error.token.start_line_index);
    break;
  case mrk_parser_unexpected_path:
    return unexpected_path_msg;
  }

  return parser->error.buf;
}
